Reference firmware for PixArt's PAA5101 sensor and evaluation board. "Hello World" and "Library" contain the exact same files. Please import just one of the two into your mBed compiler as a new program and not as a library.

Welcome to the code repository for PixArt's PAA5101 sensor and evaluation board.

For general information about this product, please visit this product's components page here:
https://os.mbed.com/components/PAA5101-Floor-Tracking-Sensor-with-Wide-/

For guides and tips on how to setup and evaluate the PAA5101 sensor with the Nordic nRF52-DK microcontroller using this reference code, please visit this guide:
https://os.mbed.com/teams/PixArt/code/5101_referenceCode/wiki/Guide-for-nRF52-DK-Platform

For guides and tips on how to setup and evaluate the PAA5101 sensor with any microcontroller using this reference code, please visit this guide:
https://os.mbed.com/teams/PixArt/code/5101_referenceCode/wiki/Guide-for-Any-Platform

Revision:
5:e6cc13f2fc8b
Parent:
4:234a8616c0a6
--- a/main.cpp	Wed Jun 13 20:30:06 2018 +0000
+++ b/main.cpp	Wed Jul 18 18:36:47 2018 +0000
@@ -1,15 +1,26 @@
 // PAA5101 Optical Tracking Minuature Chip reference code.
 // Version: 1.0
 // Latest Revision Date: 29 Jan. 2018
 // By PixArt Imaging Inc.
 // Primary Engineer: Vincent Yeh (PixArt USA)
 
+// Copyright [2018] [Vincent Yeh]
+// Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at:
+// http://www.apache.org/licenses/LICENSE-2.0
+
+
 /*
 //=======================
 //Revision History
 //=======================
-Version 1.1 -- Fixed SPI frequency from 10MHz to 2MHz.
-Version 1.0 -- First release.
+Version 1.11 -- 18 July 2018
+Added apache license notice.
+
+Version 1.1
+Fixed SPI frequency from 10MHz to 2MHz.
+
+Version 1.0
+First release.
 */
 
 #include "mbed.h"
@@ -1,15 +1,26 @@
 // PAA5101 Optical Tracking Minuature Chip reference code.
-// Version: 1.0
-// Latest Revision Date: 29 Jan. 2018
+// Version: 1.11
+// Latest Revision Date: 18 July 2018
 // By PixArt Imaging Inc.
 // Primary Engineer: Vincent Yeh (PixArt USA)